@@ -1,6 +1,6 @@
 ;;; magit.el --- A Git porcelain inside Emacs  -*- lexical-binding:t; coding:utf-8 -*-
 
-;; Copyright (C) 2008-2025 The Magit Project Contributors
+;; Copyright (C) 2008-2026 The Magit Project Contributors
 
 ;; Author: Marius Vollmer <marius.vollmer@gmail.com>
 ;;     Jonas Bernoulli <emacs.magit@jonas.bernoulli.dev>
@@ -17,15 +17,16 @@
 ;; Homepage: https://github.com/magit/magit
 ;; Keywords: git tools vc
 
-;; Package-Version: 4.4.2
+;; Package-Version: 4.5.0
+;; Package-Revision: v4.5.0-0-gc800f79c2061
 ;; Package-Requires: (
 ;;     (emacs        "28.1")
 ;;     (compat       "30.1")
-;;     (cond-let      "0.1")
+;;     (cond-let      "0.2")
 ;;     (llama         "1.0")
-;;     (magit-section "4.4")
+;;     (magit-section "4.5")
 ;;     (seq           "2.24")
-;;     (transient     "0.10")
+;;     (transient     "0.12")
 ;;     (with-editor   "3.4"))
 
 ;; SPDX-License-Identifier: GPL-3.0-or-later
@@ -519,7 +520,7 @@ is run in the top-level directory of the current working tree."
 (defun magit-read-gpg-secret-key
     (prompt &optional initial-input history predicate default)
   (require 'epa)
-  (let* ((keys (mapcan
+  (let* ((keys (seq-keep
                 (lambda (cert)
                   (and (or (not predicate)
                            (funcall predicate cert))
@@ -533,11 +534,10 @@ is run in the top-level directory of the current working tree."
                                    (if (stringp id-str)
                                        id-str
                                      (epg-decode-dn id-obj))))))
-                         (list
-                          (propertize fpr 'display
-                                      (concat (substring fpr 0 (- (length id)))
-                                              (propertize id 'face 'highlight)
-                                              " " author))))))
+                         (propertize fpr 'display
+                                     (concat (substring fpr 0 (- (length id)))
+                                             (propertize id 'face 'highlight)
+                                             " " author)))))
                 (epg-list-keys (epg-make-context epa-protocol) nil t)))
          (choice (or (and (not current-prefix-arg)
                           (or (and (length= keys 1) (car keys))
@@ -773,11 +773,12 @@ For X11 something like ~/.xinitrc should work.\n"
   (require 'magit-stash)
   (require 'magit-blame)
   (require 'magit-submodule)
-  ;; The `provide' form may be missing so we have to
-  ;; try harder to ensure this is loaded exactly once.
-  (unless (or (featurep 'magit-autoloads)
+  (unless (or noninteractive
+              ;; The `provide' form may be missing, so we have to
+              ;; try harder to ensure this is loaded exactly once.
+              (featurep 'magit-autoloads)
               (autoloadp (symbol-function 'magit-patch))
-              (load "magit-autoloads" t))
+              (load "magit-autoloads" t t))
     (require 'magit-patch)
     (require 'magit-subtree)
     (require 'magit-ediff)
